Bone.hidden constructor

Bone.hidden({
  1. Key? key,
  2. required Widget child,
  3. BoneTransition? transition,
})

A convenient constructor provides an easy and convenient way to create a a Bone which hide the child when Skeleton.isShown is true, and vice versa

Implementation

Bone.hidden({
  Key? key,
  required this.child,
  this.transition,
})  : width = 0,
      height = 0,
      number = 1,
      spacing = 0,
      variants = [1],
      baseColor = const Color(0xFFE0E0E0),
      highlightColor = const Color(0xFFF5F5F5),
      borderRadius = null,
      _isHiddenOnly = true,
      period = const Duration(milliseconds: 1500),
      direction = ShimmerDirection.ltr,
      super(key: key);